@@ -52,10 +52,12 @@ def get_time(text: str, tend_future=True):
     return time_text, time_tuple
 
 
-def get_text(time: Union[datetime, str]):
+def get_text(time: Union[datetime, str, int]):
     now = datetime.now()
     if isinstance(time, str):
         time = datetime.strptime(time, time_format)
+    elif isinstance(time, int):
+        time = datetime.fromtimestamp(time)
     duration = now - time
     reply = []
     if not duration.days:
@@ -69,6 +71,13 @@ def get_text(time: Union[datetime, str]):
     else:
         if -2 <= duration.days <= 2:
             reply.append({2: "前天", 1: "昨天", -1: "明天", -2: "后天"}.get(duration.days, ""))
+        elif time.year != now.year:
+            month_year = now.year - time.year
+            if month_year:
+                _m = {1: "去年", -1: "明年"}
+                reply.append(_m.get(month_year, time.year))
+            reply.append(f"{time.month}月")
+            reply.append(f"{time.day}号")
         else:
             month_span = now.month - time.month
             if month_span:
@@ -86,7 +95,8 @@ def get_text(time: Union[datetime, str]):
     elif 18 <= time.hour:
         reply.append("晚上")
     reply.append(f"{time.hour}点")
-    reply.append(f"{time.minute}分".zfill(3))
+    if time.minute > 0:
+        reply.append(f"{time.minute}分".zfill(3))
     return "".join(reply)
 
 
